@@ -1,7 +1,10 @@
 package Alien::TinyCC;
 
+use strict;
+use warnings;
+
 # Follow Golden's Version Rule: http://www.dagolden.com/index.php/369/version-numbers-should-be-boring/
-our $VERSION = "0.02_05";
+our $VERSION = "0.02_06";
 $VERSION = eval $VERSION;
 
 use File::ShareDir;
